#! /usr/bin/env perl
#
# tag: ewok install configure script
#

use File::Basename;
use Data::Dumper;
use strict;

my $build_dir = dirname($0);
my $cachefile = $build_dir . '/config.cache';

# Load the cache if it exists
my $cache;
if (-f $cachefile) {
    open CACHE, "<$cachefile" or die "cannot open '$cachefile' for read";
    {
        local $/;
        eval <CACHE>;
    }
    close CACHE;
}

my ($ewok_home, $okay);
# Get ewok_home directory from the user
$okay = 0;
while (! $okay) {
    my $default = "[$cache->{ewok_home}] " if $cache->{ewok_home};
    print "Install ewok where? $default";
    $ewok_home = <STDIN>;
    chomp $ewok_home;
    $ewok_home =~ s|^\s*(.*?)/?\s*$|$1|;   # Trim
    $ewok_home =~ s|^~|$ENV{HOME}| if $ENV{HOME};
    if ($ewok_home) {
        if ($ewok_home !~ m|^/|) {
            print "  $ewok_home is not an absolute path - please try again.\n";
            next;
        }
        elsif ($ewok_home !~ m|\bewok$|) {
            print "  Do you mean $ewok_home/ewok? [Y] ";
            my $add_ewok = <STDIN>;
            chomp($add_ewok);
            $add_ewok ||= 'y';
            $ewok_home .= '/ewok' if $add_ewok =~ m/^\s*y/i;
        }
        if (! -d $ewok_home) {
            print "  $ewok_home does not exist - shall I create it? [Y] ";
            my $create = <STDIN>;
            chomp($create);
            $create ||= 'y';
            $okay = ($create =~ m/^\s*y/i);
        }
        else {
            $okay = 1;
        }
    }
    # Defaults are presumably always okay
    elsif ($default) {
        ($ewok_home) = ($default =~ m/\[(.*)\]/);
        $okay = 1;
    }
}

# Get apache config directory from the user
my $apache_conf;
$okay = 0;
while (! $okay) {
    my $default = "[$cache->{apache_conf}] " if $cache->{apache_conf};
    print "Install apache config files where? $default";
    $apache_conf = <STDIN>;
    chomp $apache_conf;
    $apache_conf =~ s|^\s*(.*?)/?\s*$|$1|;   # Trim
    $apache_conf =~ s|^~|$ENV{HOME}| if $ENV{HOME};
    if ($apache_conf) {
        if ($apache_conf !~ m|^/|) {
            print "  $apache_conf is not an absolute path - please try again.\n";
        }
        elsif (! -d $apache_conf) {
            print "  $apache_conf does not exist - do you want me to create it? [Y] ";
            my $create = <STDIN>;
            chomp($create);
            $create ||= 'y';
            $okay = ($create =~ m/^\s*y/i);
        }
        else {
            $okay = 1;
        }
    }
    # Defaults are presumably always okay
    elsif ($default) {
        ($apache_conf) = ($default =~ m/\[(.*)\]/);
        $okay = 1;
    }
}

# Get httpd user from the user
my ($httpd_user, $httpd_uid);
$okay = 0;
while (! $okay) {
    my $default = "[$cache->{httpd_user}] " if $cache->{httpd_user};
    print "If installing as root, what user does your apache run as? (use . to skip) $default";
    $httpd_user = <STDIN>;
    chomp $httpd_user;
    $httpd_user =~ s|^\s*(.*?)/?\s*$|$1|;   # Trim
    if ($httpd_user eq '.') {
        $httpd_user = undef;
        $okay = 1;
    }
    elsif ($httpd_user) {
        if ($httpd_uid = (getpwnam $httpd_user)[2]) {
            $okay = 1;
        }
        else {
            print "  $httpd_user is not a valid user - please try again\n";
        }
    }
    # Defaults are presumably always okay
    elsif ($default) {
        ($httpd_user) = ($default =~ m/\[(.*)\]/);
        $httpd_uid = $cache->{httpd_uid};
        $okay = 1;
    }
}

# Save settings to cache
my $cache = {
    ewok_home => $ewok_home,
    apache_conf => $apache_conf,
    httpd_user => $httpd_user,
    httpd_uid => $httpd_uid,
};
open CACHE, ">$cachefile" or die "cannot create '$cachefile'";
print CACHE Data::Dumper->Dump([$cache], ['cache']) 
    or die "cannot write to '$cachefile'";
close CACHE;

# Finish
print "Config saved.\n";
