#! /usr/bin/env perl
#
# tag: ewok install main files installation script
#

use Getopt::Std;
use File::Basename;
use File::Path;
use File::Find;
use File::Copy qw(cp);
use File::Compare;
use strict;

my $build_dir = dirname($0);
my $cachefile = "$build_dir/config.cache";

my $hr = '-' x 78;

# Parse options
my %opts;
getopts('n', \%opts);
my $noop = $opts{n};

# Load the cache
die "cannot find cache file $cachefile - have you run configure.pl?" 
    if ! -f $cachefile;
my $cache;
open CACHE, "<$cachefile"
    or die "cannot open '$cachefile' for read";
{
    local $/;
    eval <CACHE>;
}
close CACHE;

# Make ewok_home dir if doesn't exist
if (! -d $cache->{ewok_home}) {
    print "mkdir $cache->{ewok_home}\n";
    if (! $noop) {
        my @new = mkpath($cache->{ewok_home});
        die "creating configuration directory $cache->{ewok_home} failed: $!"
            unless $new[$#new] eq $cache->{ewok_home};
        chown $cache->{httpd_uid}, -1, $cache->{ewok_home}
            if $> == 0 && $cache->{httpd_uid};
    }
}

# Copy files, using File::Find
print $hr, "\n";
print "Installing main ewok files\n";
print $hr, "\n";
my %ignore_dir = map { $_ => 1 } qw(bin build conf test {arch});
my %ignore_file = map { "$build_dir/../" . $_ => 1 } qw(lib/OF/TemplateBase.pm EXCLUDE.dist ChangeLog.old Makefile lib/Ewok/Config.pm);
find(sub {
    if ($File::Find::name ne "$build_dir/..") {   # 'next' SEGVs on 5.6
        my ($initial) = ($File::Find::name =~ m|\.\./([^/]+)|);
        my ($dir, $file);
        # Check if we want to install this file
        if (! $ignore_dir{$initial} && ! $ignore_file{$File::Find::name}) {
            # Do a mkpath for directories
            if (-d $_) {
                ($dir = $File::Find::name) =~ s|^$build_dir/../||;   #/
                if (! -e "$cache->{ewok_home}/$dir" && ! $noop) {
                    print "mkdir $cache->{ewok_home}/$dir\n";
                    mkpath "$cache->{ewok_home}/$dir"
                        or die "mkdir '$cache->{ewok_home}/$dir' failed: $!";
                    chown $cache->{httpd_uid}, -1, "$cache->{ewok_home}/$dir"
                        if $> == 0 && $cache->{httpd_uid};
                }
            }
            # Symlink links (note this works only if links are relative!)
            elsif (-l $_) {
                ($file = $File::Find::name) =~ s|^$build_dir/../||;   #/
                $dir = dirname($file);
                $dir = '' if $dir eq '.';
                my $target = readlink($_);
                # Omit absolute links
                if ($target !~ m|^\s*/|) {
                    print "ln -s $cache->{ewok_home}/$dir/$target $cache->{ewok_home}/$dir/$_\n";
                    if (! $noop) {
                        unlink "$cache->{ewok_home}/$dir/$_" if -e "$cache->{ewok_home}/$dir/$_";
                        symlink("$cache->{ewok_home}/$dir/$target", "$cache->{ewok_home}/$dir/$_")
                            or die "symlink $cache->{ewok_home}/$dir/$target, $cache->{ewok_home}/$dir/$_ failed: $!";
                        chown $cache->{httpd_uid}, -1, "$cache->{ewok_home}/$dir/$_"
                            if $> == 0 && $cache->{httpd_uid};
                    }
                }
            }
            # Copy files
            else {
                ($file = $File::Find::name) =~ s|^$build_dir/../||;   #/
                $dir = dirname($file);
                $dir = '' if $dir eq '.';
                print "cp $file $cache->{ewok_home}/$dir\n";
                if (! $noop) {
                    cp $_, "$cache->{ewok_home}/$dir"
                        or die "cp $file '$cache->{ewok_home}/$dir' failed: $!";
                    chown $cache->{httpd_uid}, -1, "$cache->{ewok_home}/$dir/$_"
                        if $> == 0 && $cache->{httpd_uid};
                }
            }
        }
    }
}, "$build_dir/..");

# Install lib/Ewok/Config.pm as a special case
print $hr, "\n";
print "Installing ewok config files\n";
print $hr, "\n";
my @conf = qw(lib/Ewok/Config.pm);
for (@conf) {
    my $filename = $_;
    if (-f "$cache->{ewok_home}/$_") {
        if (compare($_, "$cache->{ewok_home}/$filename") == 0) {
            print "-> $cache->{ewok_home}/$_ unchanged (skipping)\n";
            next;
        }
        print "-> $cache->{ewok_home}/$_ already exists but differs from our\nnew version - keeping existing\n";
        $filename .= '.new';
    }
    print "cp $_ $cache->{ewok_home}/$filename\n";
    if (! $noop) {
        cp "$build_dir/../$_", "$cache->{ewok_home}/$filename";
        chown $cache->{httpd_uid}, -1, "$cache->{ewok_home}/$filename"
            if $> == 0 && $cache->{httpd_uid};
        # Create symlink in ewok_home/conf
        if (! -e "$cache->{ewok_home}/conf") {
            mkpath "$cache->{ewok_home}/conf" 
                or die "mkdir '$cache->{ewok_home}/conf' failed: $!";
            chown $cache->{httpd_uid}, -1, "$cache->{ewok_home}/conf"
                if $> == 0 && $cache->{httpd_uid};
        }
        my $link = "$cache->{ewok_home}/conf/" . basename($_);
        if (! -e $link) {
            symlink "$cache->{ewok_home}/$_", $link
                or die "symlink $cache->{ewok_home}/$_, $link failed: $!";
            chown $cache->{httpd_uid}, -1, $link
                if $> == 0 && $cache->{httpd_uid};
        }
    }
}
