#! /usr/bin/env perl
#
# tag: ewok install config munging script
#

use Getopt::Std;
use File::Basename;
use lib './lib';
use OF::TemplateBase;
use strict;

my $build_dir = dirname($0);
my $cachefile = $build_dir . '/config.cache';

# Parse options
my %opts;
getopts('i:o:s', \%opts);
my $infile = $opts{i};
my $outfile = $opts{o};
my $settings = $opts{s};
die "infile '$infile' not found" if ! -f $infile;

# Load the cache
die "Cannot find cache file $cachefile - have you run configure.pl?" 
    if ! -f $cachefile;
my $cache;
open CACHE, "<$cachefile"
    or die "cannot open '$cachefile' for read";
{
    local $/;
    eval <CACHE>;
}
close CACHE;

# Output settings
if ($settings) {
    print "settings:\n";
    for (keys %$cache) {
        print "  $_: $cache->{$_}\n";
    }
}

# Use uppercase cache keys for munging
my %cache2 = map { uc($_) => $cache->{$_} } keys %$cache;
$cache2{DIST} = $cache->{ewok_home};

# Do the munging
my $t = OF::TemplateBase->new(map => \%cache2, open => '<', close => '>');
$t->munge(infile => $infile, outfile => $outfile);

