# tag: ewok configuration module (<DIST> version)

package Ewok::Config;

require Exporter;

@ISA = qw(Exporter);
@EXPORT = ();
@EXPORT_OK = qw(
                $EWOK_HOME
                $EWOK_METADIR
                $EWOK_LOCKDIR
                $EWOK_LOCK_TIMEOUT
                $EWOK_CLIPBOARD
                @EWOK_STAGE_DIRS
                @EWOK_PUBL_DIRS
                @EWOK_STAGE_DIRS_RX
                @EWOK_PUBL_DIRS_RX
                @EWOK_TOP_DIRS_ADD
                @EWOK_TOP_DIRS_HIDE
                @EWOK_ALL_DIRS_HIDE
                @EWOK_ADMINS
                $EWOK_ADMIN_MAILTO
                $EWOK_MAILDOMAIN
                %EWOK_TOP_DIRS_RESTRICT
                %EWOK_TOP_DIRS_BLOCK
                %EWOK_TOP_DIRS_RESTRICT_RX
                %EWOK_TOP_DIRS_BLOCK_RX
                $EWOK_ERROR_LEVEL
                $EWOK_DEBUG_MODULES
                $EWOK_ALLOW_EXEC
                $EWOK_PUBLISH
                $EWOK_PUBLISH_REWRITES
                $EWOK_STAGE_COLOR
                $EWOK_PUBLISH_COLOR
                $EWOK_EWOK_COLOR
                %EWOK_DIR_COLORS
                $EWOK_DELETE_INITIAL_HEADING
                $EWOK_AUTO_CONTENTS_STRING
                $EWOK_MARKUP_DOCTYPE
                $EWOK_USERNAME_CLEAN
                $EWOK_TEMPLATE_RE
                $EWOK_EDIT_RE
                $EWOK_WRAP_RE
                $EWOK_NONMETA_RE
                $EWOK_DIRI_OBJECT
                $EWOK_DIRN_OBJECT
                $EWOK_AUTOINDEX_OBJECT
                $EWOK_AUTOINDEX_PATH
                $EWOK_AUTHZ_OBJECT
                $EWOK_AUTHZ_PUBLISH
                $EWOK_PUBLISH_OBJECT
                $EWOK_METAMAP_OBJECT
                %EWOK_ADMIN_OBJECTS
                %EWOK_PAGES
                %EWOK_RESTRICTED_OBJECTS
                $EWOK_LOCKTYPE
             );
%EXPORT_TAGS = ( all => [ @EXPORT_OK ], );
$VERSION = '0.4.3';
$TIMESTAMP = '2002101601';

# Ewok base directory
$EWOK_HOME = '<EWOK_HOME>';

#--------------------------------------------------------------------------------
# MANDATORY: customise at least this section for your installation.

# List (space separated) of ewok staging directories (filesystem paths)
# If a directory here is outside your apache document root you should 
# probably also add the alias name to @EWOK_TOP_DIRS_ADD below
@EWOK_STAGE_DIRS = ("$EWOK_HOME/htdocs", qw(
    /PATH/TO/foo
));
# List (space separated) of ewok publish directories (filesystem paths)
# If a directory here is outside your apache document root you should 
# probably also add the alias name to @EWOK_TOP_DIRS_ADD below
@EWOK_PUBL_DIRS = qw(
);
#   /PATH/TO/publ

# List of directories (space separated) to add or hide in the ewok file 
#   manager, either at the top-level or at all levels
# @EWOK_TOP_DIRS_ADD will typically be apache Aliases (cf. ewok.conf)
@EWOK_TOP_DIRS_ADD = qw(
    foo
);
@EWOK_TOP_DIRS_HIDE = qw(
    manual mime-tmp
);
@EWOK_ALL_DIRS_HIDE = qw(
    CVS RCS
);

# List (space-separated) of usernames with ewok admin privileges
@EWOK_ADMINS = qw(
    johnny_admin jane_admin
);
# Email address for admin emails
$EWOK_ADMIN_MAILTO = 'webmaster@foo.com';

# Default maildomain (if necessary) appended to usernames for email addresses
$EWOK_MAILDOMAIN = 'foo.com';

#--------------------------------------------------------------------------------
# This next section can be customised if you wish - the defaults should be
#   reasonable to get you started.

# Restrictions on top-level trees by user (user-tree maps). 
# %TOP_DIRS_RESTRICT maps users to the set of trees they are limited to; 
# %TOP_DIRS_BLOCK maps users to a set of directories they are blocked from. 
# These are mutually exclusive, with %TOP_DIRS_RESTRICT being checked first. 
# Usernames are plain scalars or regexes (bracketed with //); scalars are 
# checked first.
%EWOK_TOP_DIRS_RESTRICT = (
    '/^guest/' => [ qw(secrets) ],
    guest1 => [ qw(secrets lies) ],
);
%EWOK_TOP_DIRS_BLOCK = (
    '/^staff/' => [ qw(everywhere_except_here) ],
    fred => [ qw(secret everywhere_except_here) ],
);

# Errors are currently just logged to the Apache error log. Change the error 
# level here to affect how much is logged. Error levels are 'debug', 'info', 
# 'warn', 'error', and 'fatal'. Only 'warn', 'info', and 'debug' are currently 
# much used.
$EWOK_ERROR_LEVEL = 'warn';
# $EWOK_ERROR_LEVEL 'debug' only logs debug statements from $EWOK_DEBUG_MODULES
# modules. These usually correspond to Ewok::* modules, but occasionally are 
# subcategorised further (e.g. Ewok::File::publish)
$EWOK_DEBUG_MODULES = [];
# $EWOK_DEBUG_MODULES = [ qw(Ewok::File::publish) ];

# System metadata directory (holds user + system metadata, not file/dir metadata)
$EWOK_METADIR = "$EWOK_HOME/var/meta";

# Lock directory
$EWOK_LOCKDIR = "$EWOK_HOME/var/lock";
$EWOK_LOCK_TIMEOUT = 30 * 60;   # Lock timeout (seconds)

# Directory to use as clipboard (cut, copy, paste)
$EWOK_CLIPBOARD = "$EWOK_HOME/var/clip";

# Flag to indicate whether to allow certain executable parameters:
#   - post_publish in publishing maps
#   - post_process in file metadata
# These are major security risks because they allow an authorised user to
#   execute arbitrary code on your machine! Probably reasonably okay in an
#   intranet context, but not elsewhere.
$EWOK_ALLOW_EXEC = 0;

# Flag to indicate whether to support staging+publishing areas
$EWOK_PUBLISH = 1;

# Flag to indicate whether to rewrite URLs when publishing
$EWOK_PUBLISH_REWRITES = 1;

# Colour settings for different trees, used for the top band in the ewok fm
#   as a visual indicator of where you are.
$EWOK_STAGE_COLOR   = '#660066';
$EWOK_PUBLISH_COLOR = '#006666';
$EWOK_EWOK_COLOR    = '#000066';

# Flag to indicate whether to default to deleting the top-level <H1> or <H2> 
# heading (usually because you're going to reuse it in the header.epl template)
# This can be further overridden by delete_initial_heading metadata items.
$EWOK_DELETE_INITIAL_HEADING = 1;

# String inserted after initial page heading when metadata 'auto_contents'
# is turned on
$EWOK_AUTO_CONTENTS_STRING = qq(<h2>Contents</h2>\n<contents>\n);

# DOCTYPE to be used when doing text markup to html
# $EWOK_MARKUP_DOCTYPE = qq();
$EWOK_MARKUP_DOCTYPE = qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">);
# $EWOK_MARKUP_DOCTYPE = qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">);
# $EWOK_MARKUP_DOCTYPE = qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">);

# Function used to munge usernames (e.g. force to lowercase)
$EWOK_USERNAME_CLEAN = undef;
# $EWOK_USERNAME_CLEAN = sub { lc "@_" };

# Ewok template objects - deleted from file lists unless template privilege
$EWOK_TEMPLATE_RE = '^(style|header|footer|content|sidebar).*\.epl$';

# File patterns that are editable
$EWOK_EDIT_RE = '\.(html?|css|xml|xsl|xps|ini|pl|cgi|php|txt)$';

# File patterns that are (potentially) page-wrapped by ewok
$EWOK_WRAP_RE = '\.(html?|xml)$';

# File patterns that should NOT have metadata stored for them
$EWOK_NONMETA_RE = '\.(css|epl|meta|map|ini|htaccess)$';

# -------------------------------------------------------------------------------
# Do not change below this point unless you know exactly what you're doing!

# Ewok (inherited) directory properties object
$EWOK_DIRI_OBJECT = '.dir.meta';
$EWOK_DIRN_OBJECT = '.dirn.meta';

# Ewok autoindex object
$EWOK_AUTOINDEX_OBJECT = 'auto.html';
$EWOK_AUTOINDEX_PATH = "$EWOK_HOME/lib/$EWOK_AUTOINDEX_OBJECT";

# Ewok authz object - deleted from file lists unless authz privilege
$EWOK_AUTHZ_OBJECT = 'authz.map';
# Whether to publish authz.map files - allows ewok file manager to do security
# checking, but means you probably need to explicitly block access to *map files
$EWOK_AUTHZ_PUBLISH = 1;

# Ewok publishing map object
$EWOK_PUBLISH_OBJECT = 'publish.map';

# Ewok metadata map object
$EWOK_METAMAP_OBJECT = 'metadata.map';

# Ewok base objects - manipulable only by ewok admin
%EWOK_ADMIN_OBJECTS = map { $_ => 1 } qw(base.epl content.epl init.epl cleanup.epl util.epl), $EWOK_METAMAP_OBJECT;

# Main ewok pages (fs-relative)
%EWOK_PAGES = map { "$EWOK_HOME/htdocs/" . $_ => 1 } qw(create.html dir.html edit.html file.html fm.html meta.html save.html view.html);

# Ewok restricted objects - objects with restricted access (see File::restrictCheck)
%EWOK_RESTRICTED_OBJECTS = map { $_ => 1 } keys(%EWOK_ADMIN_OBJECTS), $EWOK_AUTHZ_OBJECT, $EWOK_AUTOINDEX_OBJECT, $EWOK_PUBLISH_OBJECT, '.htaccess';

# Munge @EWOK_STAGE_DIRS and @EWOK_PUBL_DIRS to qr//s for performance
@EWOK_STAGE_DIRS_RX = map { qr/^$_/ } @EWOK_STAGE_DIRS;
@EWOK_PUBL_DIRS_RX  = map { qr/^$_/ } @EWOK_PUBL_DIRS;

# Pull regex keys out of user-tree maps
%EWOK_TOP_DIRS_RESTRICT_RX = map { $x = $_; s:^m?/(.*?)/$:$1:; $_ => $EWOK_TOP_DIRS_RESTRICT{$x} } grep m:^m?/.*/$:, keys %EWOK_TOP_DIRS_RESTRICT;
%EWOK_TOP_DIRS_BLOCK_RX = map { $x = $_;  s:^m?/(.*?)/$:$1:; $_ => $EWOK_TOP_DIRS_BLOCK{$x} } grep m:^m?/.*/$:, keys %EWOK_TOP_DIRS_BLOCK;

# Locking parameters
$EWOK_LOCKTYPE = 'DBM';

1;
