# tag: ewok miscellaneous html subroutines

package Ewok::HTML;

require Exporter;
use URI::Escape;
use Ewok::Authz qw(authzMatch);

@ISA = qw(Exporter);
@EXPORT = qw();
@EXPORT_OK = qw(editfmhelpLink);
%EXPORT_TAGS = ( 'all' => [@EXPORT_OK] );

use strict;

#
# Return edit, fm, and help html links for the current document
#
sub editfmhelpLink
{
    return efhLink(shift, { edit => 1, fm => 1, help => 1, %{ shift || {} }});
}

#
# Return edit, fm, and help html links for the current document
#   if the user has edit priv and the req published flag is NOT set
#
sub efhLink
{
    my $req = shift;
    my $arg = shift;
    my $count = (ref $arg eq 'HASH') ? scalar(keys %$arg) : 0;
    my $link = '';
    my $started = 0;
    if (authzMatch($req, $req->{fs_file}, 'edit') && ! $req->{published}) {
        $link .= qq([&nbsp;&nbsp;);
        my $s = uri_escape($ENV{SCRIPT_NAME}, ' ');
        if ($arg->{edit} && 
            $s =~ m/$Ewok::Config::EWOK_EDIT_RE/ && 
            $s !~ m/$Ewok::Config::EWOK_AUTOINDEX_OBJECT$/) {
            $link .= qq(<a href="/ewok/edit.html?p=$s">edit</a>);
            $link .= qq(&nbsp;&nbsp;|&nbsp;&nbsp;) if $count > 1;
        }
        $s =~ s|/[^/]+$||o;
        if ($arg->{fm}) {
            $link .= qq(<a href="/ewok/fm.html?p=$s">fm</a>);
            $link .= qq(&nbsp;&nbsp;|&nbsp;&nbsp;) if $arg->{help};
        }
        if ($arg->{help}) {
            $link .= qq(<a href="/ewok/doc/">help</a>);
        }
        $link .= qq(&nbsp;&nbsp;]);
    }
    return $link;
}

1;
