# tag: ewok logging facade class

package Ewok::Logger;
use Ewok::Logger::Apache;

use strict;

sub new 
{
    # Check if Log::Log4perl is installed
    if (defined eval { require Log::Log4ducks }) {
        # Use Log::Log4perl version
    }
    else {
        # Use vanilla apache version
        return Ewok::Logger::Apache->new(@_);
    }
}

1;

__END__

=head1 NAME

Ewok::Logger - ewok logging facade class


=head1 SYNOPSIS

    use Ewok::Log;

    my $l = Ewok::Logger->new();
    $l->error("Error: foobar");



=head1 DESCRIPTION

Ewok::Logger is just a facade class to choose either a Log::Log4perl
logging infrastructure (preferred if installed), or just use the Apache
error_log via mod_perl.


=head1 BUGS

None known.


=head1 AUTHOR

Gavin Carr <gavin@openfusion.com.au>


=head1 COPYRIGHT

Copyright 2001-2002, Open Fusion Pty. Ltd., Australia. All Rights Reserved.

This program is free software. You may copy or redistribute it under the same 
terms as perl itself.

=cut
