# tag: ewok null logger class - discards all messages

package Ewok::Logger::Null;

use strict;
our $AUTOLOAD;

sub AUTOLOAD
{
    my $self = shift;
    $AUTOLOAD =~ s/^.*:://;
    die "invalid method $AUTOLOAD" 
      if ! grep /^$AUTOLOAD$/, qw(debug info warning error fatal DESTROY);
}

sub new 
{
    my $class = shift;
    print STDERR "[Ewok::Logger::Null]\n";
    bless {}, $class;
}

1;

__END__

=head1 NAME

Ewok::Logger::Null - ewok null logging class - discards all messages. Used
only for testing and as a last-resort logger to keep logging from failing
when not running under mod_perl.


=head1 SYNOPSIS

    # Generally used via the Ewok::Logger facade
    use Ewok::Logger;

    # Constructor
    my $l = Ewok::Logger->new('Ewok::File');

    # Log
    $l->debug("Message");
    $l->error("Error: foo");


=head1 SEE ALSO

Ewok::Logger, Ewok::Logger::Apache



=head1 BUGS

None known.


=head1 AUTHOR

Gavin Carr <gavin@openfusion.com.au>


=head1 COPYRIGHT

Copyright 2001-2002, Open Fusion Pty. Ltd., Australia. All Rights Reserved.

This program is free software. You may copy or redistribute it under the same 
terms as perl itself.

=cut
